==> cmsmadesimple-1.5.3.tgz: cms/modules/nuSOAP/lang/ext/nl_NL.php <==
<?php
$lang['postinstall'] = 'nuSOAP - installatie compleet';
$lang['postuninstall'] = 'nuSOAP - succesvol verwijderd';
$lang['friendlyname'] = 'nuSOAP ';
$lang['moddescription'] = 'Een module om SOAP transacties in CMSMS te faciliteren';
$lang['installed'] = 'Ge&iuml;nstalleerd';
$lang['upgraded'] = 'Bijgewerkt';
$lang['error'] = 'Fout';
$lang['help'] = '<h3>Wat doet het?</h3>
<p>Eerlijk gezegd, niet veel. SOAP  is een protocol voor het uitwisselen van XML-gebaseerde berichten over computer netwerken, normaliter gebruik makend van HTTP/HTTPS. SOAP is geen &quot;tag&quot; module en heeft geen beheerinterface. Deze module is een simpele &quot;wrapper&quot; rond de nuSOAP PHP classes. Het verzorgt een SOAP-engine voor CMS om SOAP-berichten te faciliteren tussen een SOAP-server en een SOAP-client. Deze module kan andere modules toestaan om als server of client te fungeren.</p>
<h3>Hoe gebruikt u het?</h3>
<p>Niet. Deze module is niet bedoeld om in een pagina te gebruiken. Het is een gereedschap dat door andere modules gebruikt wordt. Moduleontwikkelaars die SOAP modules ontwikkelen voor CMS made simple wordt aangeraden eerst het nuSOAP project zelf te bekijken: <a href="http://www.scottnichol.com/soap.htm">http://www.scottnichol.com/soap.htm</a></p>
<p>Om <em>(de kans op naamconflicten te beperken)</em> is de hoofd client class bibliotheek hernoemd. Dat zijn de enige wijzigingen</p>
<h3>Rechten</h3>
<p>Voor deze module zijn geen speciale rechten nodig</p>
';
$lang['changelog'] = '<ul>
<li>1.0.1 - August, 2006
<p>Added lazy load mechanism</p>
</li>
<li>1.0 - juli, 2006
<p>Ondanks dat de module al een tijdje bestaat, is dit de eerste release</p>
</li>
</ul>
';
$lang['utma'] = '156861353.327651920156550330.1213957090.1216463492.1216721226.18';
$lang['utmz'] = '156861353.1216222697.16.9.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>

==> cmsmadesimple-1.9.4p4.tgz: cms/modules/nuSOAP/lang/ext/nl_NL.php <==
<?php
$lang['postinstall'] = 'nuSOAP - installatie compleet';
$lang['postuninstall'] = 'nuSOAP - succesvol verwijderd';
$lang['uninstalled'] = 'nuSOAP - Gede&iuml;nstalleerd';
$lang['friendlyname'] = 'nuSOAP ';
$lang['moddescription'] = 'Een module om SOAP transacties in CMSMS te faciliteren';
$lang['installed'] = 'Ge&iuml;nstalleerd';
$lang['upgraded'] = 'Bijgewerkt';
$lang['error'] = 'Fout';
$lang['help'] = '<h3>Wat doet het?</h3>
<p>Eerlijk gezegd, niet veel. SOAP  is een protocol voor het uitwisselen van XML-gebaseerde berichten over computer netwerken, normaliter gebruik makend van HTTP/HTTPS. SOAP is geen &quot;tag&quot; module en heeft geen beheerinterface. Deze module is een simpele &quot;wrapper&quot; rond de nuSOAP PHP classes. Het verzorgt een SOAP-engine voor CMS om SOAP-berichten te faciliteren tussen een SOAP-server en een SOAP-client. Deze module kan andere modules toestaan om als server of client te fungeren.</p>
<h3>Hoe gebruikt u het?</h3>
<p>Niet. Deze module is niet bedoeld om in een pagina te gebruiken. Het is een gereedschap dat door andere modules gebruikt wordt. Moduleontwikkelaars die SOAP modules ontwikkelen voor CMS made simple wordt aangeraden eerst het nuSOAP project zelf te bekijken: <a href="http://www.scottnichol.com/soap.htm">http://www.scottnichol.com/soap.htm</a></p>
<p>Om <em>(de kans op naamconflicten te beperken)</em> is de hoofd client class bibliotheek hernoemd. Dat zijn de enige wijzigingen</p>
<h3>Rechten</h3>
<p>Voor deze module zijn geen speciale rechten nodig</p>
';
$lang['changelog'] = '<ul>
<li>1.0.1 - August, 2006
<p>Added lazy load mechanism</p>
</li>
<li>1.0 - juli, 2006
<p>Ondanks dat de module al een tijdje bestaat, is dit de eerste release</p>
</li>
</ul>
';
$lang['utma'] = '156861353.799969050.1225024056.1237290807.1237299659.75';
$lang['utmz'] = '156861353.1232355789.5.3.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,29866.0.html';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>
